' Program Name:   CMDBLD.BAS
' Purpose:        Builds a batch file for a command to be applied to a list
'                 of files or directories.  The filenames of both the file/
'                 directory list and the command file are user-supplied.
'                 The file/directory names are concatenated to the command
'                 file name (another batch file) to form a user-named
'                 executable batch file.  Each record in the created
'                 executable batch file is of the form:
'                 @CALL <command file> <file/directory name>
' Created By:     Donald G. Kulle
' Last Revised:   November 4, 1992

'Default variable definition; color initialization
DEFSTR A-Z
COLOR 7, 1
CLS

'Obtain the name of the input file containing the list of files or directories
'to be concatenated with the command file name; confirm its existance.
PRINT
PRINT "Enter below the name of the text file that contains the list of files or"
PRINT "directories to be processed.  If this file is not in the current"
PRINT "working directory, provide the complete path to the file."
PRINT
INPUT "Input File Name:  ", InputFile$
ON ERROR GOTO ErrorHandling   'Triggered if file not found in next stmt.
OPEN InputFile$ FOR INPUT AS #1

'Obtain the name of the command file to be executed for each of the
'files/directories in InputFile$.  This command file should have a .bat
'extension.  Since it could be anywhere on the PATH, it is not
'possible to confirm its existance.  Capitalize this file name.
PRINT
PRINT "Enter below the name of the executable batch file that contains"
PRINT "the commands to be applied to the files/directories in the input"
PRINT "file specified above.  It is not necessary to supply the '.bat'"
PRINT "extension.  However, you must supply the complete path to this command"
PRINT "file if it is not in the current working directory or on your PATH."
PRINT
INPUT "Command File Name:  ", CommandFile$
CommandFile$ = UCASE$(CommandFile$)

'Obtain the name of the output file to house the concatenated commands.  This
'file should have a .bat extension.  Open this file for output.
PRINT
PRINT
PRINT "Enter below the name (including extension) of the output file to be"
PRINT "created by this program.  This output file will contain concatenated"
PRINT "command and file/directory names. Normally, this output file should"
PRINT "have a .bat extension.  Also, supply the path to the directory that"
PRINT "you want this file written to if other than the working directory."
PRINT
INPUT "Output File Name:  ", OutputFile$
OPEN OutputFile$ FOR OUTPUT AS #2


' **** Routine to read directory or file listing in InputFile$
'      and build a batch command file (OutputFile$) concatenating
'      the file or directory names in InputFile$ to the command file
'      name (CommandFile$).

DO UNTIL EOF(1)
        LINE INPUT #1, DirOrFileName$
        FullCommandLine$ = "@CALL " + CommandFile$ + " " + DirOrFileName$
        PRINT #2, FullCommandLine$
LOOP

'Process complete.  Close files and exit to system
CLOSE #1: CLOSE #2
SYSTEM
END



'*** Error Handling Routine ***
ErrorHandling:

SELECT CASE ERR
        CASE 53                 'File <InputFIle$> not found
                PRINT
                COLOR 28, 1
                PRINT "File '"; UCASE$(InputFile$); "' not found. "
                PRINT
                COLOR 7, 1
                PRINT "Create this file and/or confirm its location; then try again!"
                PRINT
                PRINT
                SYSTEM  'Exit this program


END SELECT





